==> estateplat-common-1.2.4-20210420.022601-719-sources.jar: cn/gtmap/estateplat/model/server/core/BdcTdcbjyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;
/**
 * @author <a href="mailto:jiangganzhi@gtmap.cn">jiangganzhi</a>
 * @version V1.0, 2021/3/16
 * @description 土地承包经营权
 */
@Table(name = "BDC_TDCBJYQ")
public class BdcTdcbjyq extends QllxParent implements QllxVo{
    private String fj;
    private String bz;
    private String zxyy;
    private String zxdbr;
    private String zxdbsj;
    private String dkmc;
    private Date cbkssj;
    private Date cbjssj;
    private Double cbmj;
    private String tdsyqxz;
    private String yzyfs;
    private Integer syzcl;
    private String fbfqc;
    private String fbffzr;
    private String fbflxdh;
    private String cbfw;
    private String qqqk;
    private String cyzl;
    private String zxywh;
    private String syttlx;
    @Override
    public String getFj() {
        return fj;
    }

    @Override
    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public String getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(String zxdbsj) {
        this.zxdbsj = zxdbsj;
    }

    public String getDkmc() {
        return dkmc;
    }

    public void setDkmc(String dkmc) {
        this.dkmc = dkmc;
    }

    public Date getCbkssj() {
        return cbkssj;
    }

    public void setCbkssj(Date cbkssj) {
        this.cbkssj = cbkssj;
    }

    public Date getCbjssj() {
        return cbjssj;
    }

    public void setCbjssj(Date cbjssj) {
        this.cbjssj = cbjssj;
    }

    public Double getCbmj() {
        return cbmj;
    }

    public void setCbmj(Double cbmj) {
        this.cbmj = cbmj;
    }

    public String getTdsyqxz() {
        return tdsyqxz;
    }

    public void setTdsyqxz(String tdsyqxz) {
        this.tdsyqxz = tdsyqxz;
    }

    public String getYzyfs() {
        return yzyfs;
    }

    public void setYzyfs(String yzyfs) {
        this.yzyfs = yzyfs;
    }

    public Integer getSyzcl() {
        return syzcl;
    }

    public void setSyzcl(Integer syzcl) {
        this.syzcl = syzcl;
    }

    public String getFbfqc() {
        return fbfqc;
    }

    public void setFbfqc(String fbfqc) {
        this.fbfqc = fbfqc;
    }

    public String getFbffzr() {
        return fbffzr;
    }

    public void setFbffzr(String fbffzr) {
        this.fbffzr = fbffzr;
    }

    public String getFbflxdh() {
        return fbflxdh;
    }

    public void setFbflxdh(String fbflxdh) {
        this.fbflxdh = fbflxdh;
    }

    public String getCbfw() {
        return cbfw;
    }

    public void setCbfw(String cbfw) {
        this.cbfw = cbfw;
    }

    public String getQqqk() {
        return qqqk;
    }

    public void setQqqk(String qqqk) {
        this.qqqk = qqqk;
    }

    public String getCyzl() {
        return cyzl;
    }

    public void setCyzl(String cyzl) {
        this.cyzl = cyzl;
    }

    public String getZxywh() {
        return zxywh;
    }

    public void setZxywh(String zxywh) {
        this.zxywh = zxywh;
    }

    public String getSyttlx() {
        return syttlx;
    }

    public void setSyttlx(String syttlx) {
        this.syttlx = syttlx;
    }
}

==> estateplat-common-1.2.4-20210913.081206-870-sources.jar: cn/gtmap/estateplat/model/server/core/BdcTdcbjyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;
/**
 * @author <a href="mailto:jiangganzhi@gtmap.cn">jiangganzhi</a>
 * @version V1.0, 2021/3/16
 * @description 土地承包经营权
 */
@Table(name = "BDC_TDCBJYQ")
public class BdcTdcbjyq extends QllxParent implements QllxVo{
    private String fj;
    private String bz;
    private String zxyy;
    private String zxdbr;
    private String zxdbsj;
    private String dkmc;
    private Date cbkssj;
    private Date cbjssj;
    private Double cbmj;
    private String tdsyqxz;
    private String yzyfs;
    private Integer syzcl;
    private String fbfqc;
    private String fbffzr;
    private String fbflxdh;
    private String cbfw;
    private String qqqk;
    private String cyzl;
    private String zxywh;
    private String syttlx;

    private String fbfdm ;//发包方代码
    private String cbhtbm ;//承包合同代码
    private String ydyhfl ;//用地用海分类
    private String tdcbht ;//土地承包合同

    public String getFbfdm() {
        return fbfdm;
    }

    public void setFbfdm(String fbfdm) {
        this.fbfdm = fbfdm;
    }

    public String getCbhtbm() {
        return cbhtbm;
    }

    public void setCbhtbm(String cbhtbm) {
        this.cbhtbm = cbhtbm;
    }

    public String getYdyhfl() {
        return ydyhfl;
    }

    public void setYdyhfl(String ydyhfl) {
        this.ydyhfl = ydyhfl;
    }

    public String getTdcbht() {
        return tdcbht;
    }

    public void setTdcbht(String tdcbht) {
        this.tdcbht = tdcbht;
    }

    @Override
    public String getFj() {
        return fj;
    }

    @Override
    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public String getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(String zxdbsj) {
        this.zxdbsj = zxdbsj;
    }

    public String getDkmc() {
        return dkmc;
    }

    public void setDkmc(String dkmc) {
        this.dkmc = dkmc;
    }

    public Date getCbkssj() {
        return cbkssj;
    }

    public void setCbkssj(Date cbkssj) {
        this.cbkssj = cbkssj;
    }

    public Date getCbjssj() {
        return cbjssj;
    }

    public void setCbjssj(Date cbjssj) {
        this.cbjssj = cbjssj;
    }

    public Double getCbmj() {
        return cbmj;
    }

    public void setCbmj(Double cbmj) {
        this.cbmj = cbmj;
    }

    public String getTdsyqxz() {
        return tdsyqxz;
    }

    public void setTdsyqxz(String tdsyqxz) {
        this.tdsyqxz = tdsyqxz;
    }

    public String getYzyfs() {
        return yzyfs;
    }

    public void setYzyfs(String yzyfs) {
        this.yzyfs = yzyfs;
    }

    public Integer getSyzcl() {
        return syzcl;
    }

    public void setSyzcl(Integer syzcl) {
        this.syzcl = syzcl;
    }

    public String getFbfqc() {
        return fbfqc;
    }

    public void setFbfqc(String fbfqc) {
        this.fbfqc = fbfqc;
    }

    public String getFbffzr() {
        return fbffzr;
    }

    public void setFbffzr(String fbffzr) {
        this.fbffzr = fbffzr;
    }

    public String getFbflxdh() {
        return fbflxdh;
    }

    public void setFbflxdh(String fbflxdh) {
        this.fbflxdh = fbflxdh;
    }

    public String getCbfw() {
        return cbfw;
    }

    public void setCbfw(String cbfw) {
        this.cbfw = cbfw;
    }

    public String getQqqk() {
        return qqqk;
    }

    public void setQqqk(String qqqk) {
        this.qqqk = qqqk;
    }

    public String getCyzl() {
        return cyzl;
    }

    public void setCyzl(String cyzl) {
        this.cyzl = cyzl;
    }

    public String getZxywh() {
        return zxywh;
    }

    public void setZxywh(String zxywh) {
        this.zxywh = zxywh;
    }

    public String getSyttlx() {
        return syttlx;
    }

    public void setSyttlx(String syttlx) {
        this.syttlx = syttlx;
    }
}
